@@ -42,7 +42,7 @@ _CONFIGS = {
               ['kv', 1, 'str', ('key', 'value')],
               ],
          'label_shape_color': 'content_class'.split(','),
-         'default_label': json.dumps({'text': '', 'class': '其它类', 'kv': 'value'}, ensure_ascii=False),
+         'default_label': json.dumps({'text': '', 'class': '其他类', 'kv': 'value'}, ensure_ascii=False),
          },
     'XlCoco': {
         '_attrs':
